@@ -9,16 +9,31 @@ use POSIX qw(strftime);
 sub run {
     my ($self, %args) = @_;
 
+    my $source = $args{'filename'};
+
     my $server  = $ENV{NOPASTE_SSH_SERVER}  || return (0,"No NOPASTE_SSH_SERVER set");
     my $docroot = $ENV{NOPASTE_SSH_DOCROOT} || return (0, "No NOPASTE_SSH_DOCROOT set");
     my $topurl  = $ENV{NOPASTE_SSH_WEBPATH} || "http://$server";
     my $mode    = $ENV{NOPASTE_SSH_MODE}    || undef;
+    my $usedesc = defined $ENV{NOPASTE_SSH_USE_DESCRIPTION}
+                    ? $ENV{NOPASTE_SSH_USE_DESCRIPTION}
+                    : 1;
 
     my $date = strftime("%Y-%m-%d",localtime());
-    my ($ext) = defined $args{'filename'} && $args{'filename'} =~ /(\.[^.]+?)$/ ? $1 : '';
+    my ($ext) = defined $source && $source =~ s/(\.[^.]+?)$// ? $1 : '';
+
+    my $suffix = $ext;
+    if ($usedesc) {
+        if (not $args{'desc'}) {
+            my ($vol, $dirs, $file) = File::Spec->splitpath($source);
+            $args{'desc'} = $file || '';
+        }
+        $suffix = ($args{'desc'} ? '-' : '') . $args{'desc'} . $suffix;
+    }
+
     my $tmp = File::Temp->new(
         TEMPLATE => "${date}XXXXXXXX",
-        SUFFIX   => $ext,
+        SUFFIX   => $suffix,
         UNLINK   => 1,
     );
     my $filename = $tmp->filename;
@@ -73,7 +88,27 @@ The path for URLs. For example: C<http://sartak.org/paste>.
 Octal permissions mode to set for the temporary file before uploading.
 For example: C<0644>.
 
+=item NOPASTE_SSH_USE_DESCRIPTION
+
+Use the supplied description in the paste filename for easier identification of
+pastes.  Defaults to the source filename, if any, but is overridden by an
+explicit C<-d> or C<--description> command line argument.
+
 =back
 
+=head1 APACHE CONFIGURATION RECOMMENDATIONS
+
+The following is a recommended Apache configuration you can drop into
+C<.htaccess> in your paste dir.
+
+    RemoveHandler .cgi
+    RemoveHandler .pl
+    AddDefaultCharset utf-8
+    Options -ExecCGI -FollowSymLinks -Includes -MultiViews
+
+It prevents common means of script execution so that C<.pl> and C<.cgi>
+files won't run and defaults the character set to UTF-8 so browsers
+don't have to guess wrong.
+
 =cut
 
